.. SPDX-FileCopyrightText: 2008-2025 Luis Falcón <falcon@gnuhealth.org>
.. SPDX-FileCopyrightText: 2011-2025 GNU Solidario <health@gnusolidario.org>
..
.. SPDX-License-Identifier: CC-BY-SA-4.0 

The GNU Health HIS Installer and Manager
========================================

The gnuhealth-control is a single-entry point to install, setup and manage
the GNU Health Hospital Management System

Installation
------------
You can install the GNU Health HMIS client using your distro package or via pip::

 $ pip install --upgrade gnuhealth-control


Technology
----------
The GNU Health HMIS client is a self-contained curses Python application.


Development
-----------
The development of gnuhealth-control will be done at Codeberg.

The development mailing list is at health-dev@gnu.org 
General questions can be done on health@gnu.org mailing list.

Note: You need to subscribe before posting or the messages will be automatically
discarded. More at: https://docs.gnuhealth.org/his/support.html

Homepage
--------
https://www.gnuhealth.org


Documentation
-------------

https://docs.gnuhealth.org
